@@ -1,6 +1,6 @@
 import contextlib
 import logging
-import typing, re
+import re
 from arango import ArangoClient
 from django.conf import settings
 from rest_framework.response import Response
@@ -10,11 +10,23 @@ from rest_framework.exceptions import ValidationError, NotFound
 from stix2arango.services import ArangoDBService
 from . import conf
 
-from django.http import HttpResponse
 from django.conf import settings
-from rest_framework import decorators, response, status
-
 
+ATTACK_FORMS = {
+    "Tactic": [dict(type="x-mitre-tactic")],
+    "Technique": [
+        dict(type="attack-pattern", x_mitre_is_subtechnique=False),
+        dict(type="attack-pattern", x_mitre_is_subtechnique=None),
+    ],
+    "Sub-technique": [dict(type="attack-pattern", x_mitre_is_subtechnique=True)],
+    "Mitigation": [dict(type="course-of-action")],
+    "Group": [dict(type="intrusion-set")],
+    "Software": [dict(type="malware"), dict(type="tool"), dict(type='software')],
+    "Campaign": [dict(type="campaign")],
+    "Data Source": [dict(type="x-mitre-data-source")],
+    "Data Component": [dict(type="x-mitre-data-component")],
+    "Asset": [dict(type="x-mitre-asset")],
+}
 ATTACK_FLOW_TYPES = ["attack-flow", "attack-action"]
 
 SDO_TYPES = set(
@@ -54,7 +66,7 @@ SCO_TYPES = set(
         "artifact",
         "autonomous-system",
         "bank-account",
-        "bank-card",
+        "payment-card",
         "cryptocurrency-transaction",
         "cryptocurrency-wallet",
         "directory",
@@ -118,6 +130,15 @@ OBJECT_TYPES = (
     SDO_TYPES.union(SCO_TYPES).union(["relationship"]).union(SMO_TYPES).union()
 )
 
+TLP_VISIBLE_TO_ALL = (
+    # tlpv2
+    "marking-definition--bab4a63c-aed9-4cf5-a766-dfca5abac2bb",
+    "marking-definition--94868c89-83c2-464b-929b-a1a8aa3c8487",
+    # tlpv1
+    "marking-definition--613f2e26-407d-48c7-9eca-b8e91df99dc9",
+    "marking-definition--34098fce-860f-48ae-8e50-ebd3cc5e41da",
+)
+
 
 def positive_int(integer_string, cutoff=None, default=1):
     """
@@ -325,10 +346,10 @@ class ArangoDBHelper:
                 (
                     doc.type == 'artifact' AND CONTAINS(LOWER(doc.payload_bin), @search_value) OR
                     doc.type == 'autonomous-system' AND CONTAINS(LOWER(doc.number), @search_value) OR
-                    doc.type == 'bank-account' AND CONTAINS(LOWER(doc.iban_number), @search_value) OR
-                    doc.type == 'bank-card' AND CONTAINS(LOWER(doc.number), @search_value) OR
-                    doc.type == 'cryptocurrency-transaction' AND CONTAINS(LOWER(doc.hash), @search_value) OR
-                    doc.type == 'cryptocurrency-wallet' AND CONTAINS(LOWER(doc.hash), @search_value) OR
+                    doc.type == 'bank-account' AND CONTAINS(LOWER(doc.iban), @search_value) OR
+                    doc.type == 'payment-card' AND CONTAINS(LOWER(doc.value), @search_value) OR
+                    doc.type == 'cryptocurrency-transaction' AND CONTAINS(LOWER(doc.value), @search_value) OR
+                    doc.type == 'cryptocurrency-wallet' AND CONTAINS(LOWER(doc.value), @search_value) OR
                     doc.type == 'directory' AND CONTAINS(LOWER(doc.path), @search_value) OR
                     doc.type == 'domain-name' AND CONTAINS(LOWER(doc.value), @search_value) OR
                     doc.type == 'email-addr' AND CONTAINS(LOWER(doc.value), @search_value) OR
@@ -339,7 +360,7 @@ class ArangoDBHelper:
                     doc.type == 'mac-addr' AND CONTAINS(LOWER(doc.value), @search_value) OR
                     doc.type == 'mutex' AND CONTAINS(LOWER(doc.value), @search_value) OR
                     doc.type == 'network-traffic' AND CONTAINS(LOWER(doc.protocols), @search_value) OR
-                    doc.type == 'phone-number' AND CONTAINS(LOWER(doc.number), @search_value) OR
+                    doc.type == 'phone-number' AND CONTAINS(LOWER(doc.value), @search_value) OR
                     doc.type == 'process' AND CONTAINS(LOWER(doc.pid), @search_value) OR
                     doc.type == 'software' AND CONTAINS(LOWER(doc.name), @search_value) OR
                     doc.type == 'url' AND CONTAINS(LOWER(doc.value), @search_value) OR
@@ -412,19 +433,43 @@ class ArangoDBHelper:
         other_filters = []
         search_filters = ["doc._is_latest == TRUE"]
         if term := self.query.get("labels"):
-            bind_vars["labels"] = term
-            other_filters.append("doc.labels[? ANY FILTER CONTAINS(CURRENT, @labels)]")
+            bind_vars["labels"] = term.lower()
+            other_filters.append("doc.labels[? ANY FILTER CONTAINS(LOWER(CURRENT), @labels)]")
 
         if term := self.query.get("name"):
-            bind_vars["name"] = "%" + self.get_like_literal(term) + "%"
-            search_filters.append("doc.name LIKE @name")
+            bind_vars["name"] = "%" + self.get_like_literal(term).lower() + "%"
+            other_filters.append("LOWER(doc.name) LIKE @name")
+
+        if ttp_type := self.query.get('ttp_type'):
+            if ttp_type in ['cve', 'location', 'cwe']:
+                ttp_types_mapping = dict(cve='vulnerability', cwe='weakness', location='location')
+                bind_vars['types'] = [ttp_types_mapping[ttp_type]]
+            elif ttp_type.endswith('-attack'):
+                bind_vars['mitre_domain'] = ttp_type
+                search_filters.append('doc.x_mitre_domains IN [@mitre_domain]')
+            else:
+                ttp_source_name_mapping = dict(capec='capec', atlas='mitre-atlas', disarm='DISARM')
+                bind_vars['ttp_source_name'] = ttp_source_name_mapping.get(ttp_type, '===|===')
+                other_filters.append('doc.external_references[0].source_name == @ttp_source_name')
+
+        if ttp_object_type := self.query_as_array('ttp_object_type'):
+            form_list = []
+            for form in ttp_object_type:
+                form_list.extend(ATTACK_FORMS.get(form, []))
+
+            if form_list:
+                other_filters.append(
+                    "@attack_form_list[? ANY FILTER MATCHES(doc, CURRENT)]"
+                )
+                bind_vars["attack_form_list"] = form_list
+
+        if ttp_id := self.query.get('ttp_id'):
+            bind_vars['ttp_id'] = ttp_id
+            other_filters.append('doc.external_references[0].external_id == @ttp_id')
 
         if q := self.query.get("visible_to"):
             bind_vars["visible_to"] = q
-            bind_vars["marking_visible_to_all"] = (
-                "marking-definition--bab4a63c-aed9-4cf5-a766-dfca5abac2bb",
-                "marking-definition--94868c89-83c2-464b-929b-a1a8aa3c8487",
-            )
+            bind_vars["marking_visible_to_all"] = TLP_VISIBLE_TO_ALL
             search_filters.append(
                 "(doc.created_by_ref IN [@visible_to, NULL] OR @marking_visible_to_all ANY IN doc.object_marking_refs)"
             )
@@ -481,21 +526,20 @@ class ArangoDBHelper:
             late_filters.append("FILTER doc.type IN @types")
             bind_vars["types"] = types
 
-        if not self.query_as_bool('include_embedded_sros', False):
-            late_filters.append('FILTER doc._is_ref != TRUE')
-        
+        if not self.query_as_bool("include_embedded_sros", False):
+            late_filters.append("FILTER doc._is_ref != TRUE")
+
         visible_to_filter = ""
-        
+
         if created_by_refs := self.query_as_array("created_by_refs"):
-            late_filters.append("FILTER doc.created_by_ref IN @created_by_refs OR doc.id == @id")
+            late_filters.append(
+                "FILTER doc.created_by_ref IN @created_by_refs OR doc.id == @id"
+            )
             bind_vars["created_by_refs"] = created_by_refs
-            
+
         if q := self.query.get("visible_to"):
             bind_vars["visible_to"] = q
-            bind_vars["marking_visible_to_all"] = (
-                "marking-definition--bab4a63c-aed9-4cf5-a766-dfca5abac2bb",
-                "marking-definition--94868c89-83c2-464b-929b-a1a8aa3c8487",
-            )
+            bind_vars["marking_visible_to_all"] = TLP_VISIBLE_TO_ALL
             visible_to_filter = "FILTER doc.created_by_ref == @visible_to OR @marking_visible_to_all ANY IN doc.object_marking_refs OR doc.created_by_ref == NULL"
 
         query = """
@@ -534,7 +578,7 @@ class ArangoDBHelper:
             search_filters.append("doc._target_type IN @target_ref_type")
 
         if term := self.query.get("relationship_type"):
-            bind_vars["relationship_type"] = "%" + self.get_like_literal(term) + "%"
+            bind_vars["relationship_type"] = "%" + self.get_like_literal(term).lower() + "%"
             search_filters.append("doc.relationship_type LIKE @relationship_type")
 
         if not self.query_as_bool("include_embedded_refs", True):
@@ -556,10 +600,7 @@ class ArangoDBHelper:
 
         if q := self.query.get("visible_to"):
             bind_vars["visible_to"] = q
-            bind_vars["marking_visible_to_all"] = (
-                "marking-definition--bab4a63c-aed9-4cf5-a766-dfca5abac2bb",
-                "marking-definition--94868c89-83c2-464b-929b-a1a8aa3c8487",
-            )
+            bind_vars["marking_visible_to_all"] = TLP_VISIBLE_TO_ALL
             search_filters.append(
                 "(doc.created_by_ref IN [@visible_to, NULL] OR @marking_visible_to_all ANY IN doc.object_marking_refs)"
             )
@@ -579,7 +620,7 @@ class ArangoDBHelper:
         # return HttpResponse(content=f"{query}\n\n// {__import__('json').dumps(bind_vars)}")
         return self.execute_query(query, bind_vars=bind_vars)
 
-    def delete_report_object(self, report_id, object_id):
+    def delete_report_objects(self, report_id, object_ids):
         db_service = ArangoDBService(
             self.DB_NAME,
             [],
@@ -592,69 +633,56 @@ class ArangoDBHelper:
             host_url=settings.ARANGODB_HOST_URL,
         )
         query = """
-        let doc_ids = (
             FOR doc IN @@view
-            SEARCH doc.id IN [@object_id, @report_id] AND doc._stixify_report_id == @report_id
-            SORT doc.object_refs
-            RETURN [doc._id, doc.id]
-        )
-        LET doc_id = FIRST(doc_ids[* FILTER CURRENT[1]== @object_id])
-        LET report_id = FIRST(FIRST(doc_ids[* FILTER CURRENT[1] == @report_id]))
-
-        RETURN [report_id, doc_id, (FOR d IN APPEND([doc_id], (
-                FOR doc IN @@view
-                SEARCH doc._from == doc_id[0] OR doc._to == doc_id[0]
-                RETURN [doc._id, doc.id])
-            )
-        FILTER d != NULL
-        RETURN d)]
+            SEARCH (doc.id IN @object_ids OR (doc.source_ref IN @object_ids AND doc.relationship_type == "detected-using") OR doc.id == @report_id) AND doc._stixify_report_id == @report_id
+            RETURN [doc._id, doc._to]
         """
-        bind_vars = {
-            "@view": self.collection,
-            "object_id": object_id,
-            "report_id": report_id,
-        }
-        report_idkey, doc_id, ids_to_be_removed = self.execute_query(
-            query, bind_vars=bind_vars, paginate=False
-        )[0]
-        # separate into collections
-        collections = {}
-        bind_vars = {"ckeys": {}}
-        queries = []
-        stix_ids = []
-        for key_id, stix_id in ids_to_be_removed:
-            stix_ids.append(stix_id)
-            try:
-                db_service.db.delete_document(key_id)
-            except Exception as e:
-                logging.exception("failed to delete object %s", key_id)
-
-        if not stix_ids:
-            return response.Response(status=status.HTTP_204_NO_CONTENT)
-        resp = self.execute_query(
-            """
-            FOR doc in @@collection FILTER doc._id == @report_idkey
-                UPDATE {_key: doc._key} WITH {object_refs: REMOVE_VALUES(doc.object_refs, @stix_ids)} IN @@collection
-                RETURN {new_length: LENGTH(NEW.object_refs), old_length: LENGTH(doc.object_refs)}
-                """,
-            bind_vars={
-                "report_idkey": report_idkey,
-                "stix_ids": stix_ids,
-                "@collection": report_idkey.split("/")[0],
-            },
+        objects_to_delete: list[tuple[str, str]] = self.execute_query(
+            query,
             paginate=False,
+            bind_vars={
+                "@view": self.collection,
+                "object_ids": object_ids,
+                "report_id": report_id,
+            },
         )
-        logging.info(
-            f"removed references from report.object_refs: {resp} // {ids_to_be_removed}"
-        )
-        if doc_id:
-            doc_collection_name = doc_id[0].split("/")[0]
-            db_service.update_is_latest_several_chunked(
-                list(set([object_id] + stix_ids)),
-                doc_collection_name,
-                doc_collection_name.removesuffix("_vertex_collection").removesuffix(
-                    "_edge_collection"
-                )
-                + "_edge_collection",
+        object_keys = []
+        report_ref_ids = []
+        report_id = None
+        collection_name = None
+        for r2 in objects_to_delete:
+            for r in r2:
+                if not r:
+                    continue
+
+                collection_, _, _key = r.partition("/")
+                stix_id, _, _ = _key.partition("+")
+                if "report" in r:
+                    report_id = r
+                    collection_name = collection_
+                else:
+                    object_keys.append(dict(_key=_key))
+                    report_ref_ids.append(stix_id)
+
+        if report_ref_ids and collection_name:
+            db_service.db.collection(collection_name).delete_many(
+                object_keys, refill_index_caches=True, sync=True
             )
-        return response.Response(status=status.HTTP_204_NO_CONTENT)
+            db_service.db.collection(
+                collection_name.removesuffix("_vertex_collection") + "_edge_collection"
+            ).delete_many(object_keys, refill_index_caches=True, sync=True)
+            resp = self.execute_query(
+                """
+                FOR doc in @@collection FILTER doc._id == @report_idkey
+                    UPDATE {_key: doc._key} WITH {object_refs: REMOVE_VALUES(doc.object_refs, @stix_ids)} IN @@collection
+                    RETURN {new_length: LENGTH(NEW.object_refs), old_length: LENGTH(doc.object_refs)}
+                    """,
+                bind_vars={
+                    "report_idkey": report_id,
+                    "stix_ids": report_ref_ids,
+                    "@collection": collection_name,
+                },
+                paginate=False,
+            )
+            db_service.update_is_latest_several(report_ref_ids, collection_name)
+        return Response(dict(removed_objects=report_ref_ids))
