@@ -1,3 +1,4 @@
+import contextlib
 from dogesec_commons.objects import conf
 from dogesec_commons.utils.schemas import DEFAULT_400_RESPONSE
 from .helpers import (
@@ -10,6 +11,7 @@ from .helpers import (
     SMO_SORT_FIELDS,
     SCO_SORT_FIELDS,
     SDO_SORT_FIELDS,
+    ATTACK_FORMS,
 )
 from drf_spectacular.utils import extend_schema_view, extend_schema, OpenApiParameter
 from drf_spectacular.types import OpenApiTypes
@@ -63,6 +65,35 @@ class QueryParams:
         OpenApiParameter("sort", enum=SCO_SORT_FIELDS),
     ]
 
+    ttp_type = OpenApiParameter(
+        "ttp_type",
+        description=textwrap.dedent(
+            """
+            Filter results by source of TTP object.
+            """
+        ),
+        enum=['cve', 'cwe', 'enterprise-attack', 'ics-attack', 'mobile-attack', 'capec', 'location', 'disarm', 'atlas']
+    )
+    ttp_object_type = OpenApiParameter(
+        "ttp_object_type",
+        many=True,
+        explode=False,
+        description=textwrap.dedent(
+            """
+            Further filter results by properties more specific to certain ttp types.
+            """
+        ),
+        enum=list(ATTACK_FORMS),
+    )
+    ttp_id = OpenApiParameter(
+        "ttp_id",
+        description=textwrap.dedent(
+            """
+            Filter results by external ID of TTP object. i.e T1047, CVE-2023-12345
+            """
+        ),
+    )
+    
     name = OpenApiParameter(
         "name",
         description=textwrap.dedent(
@@ -96,6 +127,7 @@ class QueryParams:
         name,
         labels,
         sdo_types,
+        ttp_type, ttp_id, ttp_object_type,
         OpenApiParameter("sort", enum=SDO_SORT_FIELDS),
     ]
 
@@ -277,18 +309,50 @@ class SingleObjectView(viewsets.ViewSet):
         )
 
 
+OBJECT_ID_ARRAY = {
+    "type": "array",
+    "items": {
+        "type": "string",
+        "pattern": "^[a-z\\-]+--[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$",
+        "example": "ipv4-addr--ba6b3f21-d818-4e7c-bfff-765805177512",
+    },
+}
+DELETE_OBJECTS_RESPONSE = {
+    "type": "object",
+    "properties": {"removed_objects": OBJECT_ID_ARRAY},
+    "required": ["removed_objects"],
+    "additionalProperties": False,
+}
+
+
 @extend_schema_view(
     destroy_in_report=extend_schema(
         summary="Delete an Object from a Report",
+        description=textwrap.dedent(
+            """
+            Occasionally txt2stix will create an erroneous extraction from a text document. This endpoint allows you to remove the STIX object created for such extractions.
+
+            This request will delete the object ID specified in the request, and ALL relationship objects that reference the Objects ID in either the `source_ref` or `target_ref` property of the relationship object. If the object passed is an SCO object, it will also delete any linked Indicators (and relationships between Indicator and SCO), to ensure all objects created by txt2stix for the SCO are removed (if no Indicator exists, it will just delete the SCO).
+
+            You can safely to run this request on SCOs that are seen in multiple reports. This is because in the database multiple versions of the same SCO object exist, one for each report (identified using the field `_stix2arango=<REPORT_ID>`). All objects created during the processing of this report have this field too.
+
+            **DANGER:** This action is irreversible.
+            """
+        ),
+    ),
+    delete_multi=extend_schema(
+        request={"application/json": OBJECT_ID_ARRAY},
+        responses={200: DELETE_OBJECTS_RESPONSE},
+        summary="Delete multiple Objects from a Report",
         description=textwrap.dedent(
             """
             Occasionally txt2stix will create an erroneous extraction from a text document. This endpoint allows you to remove the STIX objects created for such extractions.
 
-            This request will delete the object ID specified in the request, and ALL relationship objects that reference this Objects ID in either the `source_ref` or `target_ref` property of the relationship object.
+            This request will delete the object IDs specified in the request, and ALL relationship objects that reference the Objects IDs in either the `source_ref` or `target_ref` property of the relationship object. If any of the objects passed are an SCO object, it will also delete any linked Indicators (and relationships between Indicator and SCO), to ensure all objects created by txt2stix for the SCO are removed (if no Indicator exists, it will just delete the SCO).
 
-            You can safely to run this request on SCOs that are seen in multiple reports. Whilst Obstracts shows a single SCO with the same value with the same STIX ID (e.g. `1.1.1.1`), in the database multiple versions of the same SCO object exist, one for each report (identified using the field `_stix2arango=<REPORT_ID`). All objects created during the processing of this report have this field too.
+            You can safely to run this request on SCOs that are seen in multiple reports. This is because in the database multiple versions of the same SCO object exist, one for each report (identified using the field `_stix2arango=<REPORT_ID>`). All objects created during the processing of this report have this field too.
 
-            **DANGER:** This action is irreversible. It also can create issues if not run carefully. For example, assume you have a connection from a report object as follows; Report -> Indicator -> IPv4. Should you delete the Indicator objects in this example, the IPv4 will no longer be directly connected to the report (though it will still appear in the report bundle, and the reports `object_refs` property).
+            **DANGER:** This action is irreversible.
             """
         ),
     ),
@@ -303,9 +367,24 @@ class ObjectsWithReportsView(SingleObjectView):
     def destroy_in_report(
         self, request, *args, object_id=None, report_id=None, **kwargs
     ):
+        ArangoDBHelper(
+            conf.ARANGODB_DATABASE_VIEW, request
+        ).delete_report_objects(report_id=report_id, object_ids=[object_id])
+        return Response(status=204)
+
+    @decorators.action(
+        detail=False,
+        methods=["POST"],
+        url_path=r"reports/(?P<report_id>report--[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12})/remove_objects",
+    )
+    def delete_multi(self, request, *args, report_id=None, **kwargs):
+        data = request.data
+        object_ids = []
+        with contextlib.suppress(Exception):
+            object_ids = [str(d) for d in data]
         return ArangoDBHelper(
             conf.ARANGODB_DATABASE_VIEW, request
-        ).delete_report_object(report_id=report_id, object_id=object_id)
+        ).delete_report_objects(report_id=report_id, object_ids=object_ids)
 
 
 @extend_schema_view(
@@ -344,10 +423,10 @@ class SDOView(viewsets.ViewSet):
 
             * `artifact.payload_bin`
             * `autonomous-system.number`
-            * `bank-account.iban_number`
-            * `bank-card.number`
-            * `cryptocurrency-transaction.hash`
-            * `cryptocurrency-wallet.hash`
+            * `bank-account.iban`
+            * `payment-card.value`
+            * `cryptocurrency-transaction.value`
+            * `cryptocurrency-wallet.value`
             * `directory.path`
             * `domain-name.value`
             * `email-addr.value`
@@ -358,7 +437,7 @@ class SDOView(viewsets.ViewSet):
             * `mac-addr.value`
             * `mutex.value`
             * `network-traffic.protocols`
-            * `phone-number.number`
+            * `phone-number.value`
             * `process.pid`
             * `software.name`
             * `url.value`
