@@ -195,16 +195,16 @@ sco_objects = [
     {"type": "autonomous-system", "number": "AS12345", "id": "as-1"},
     {
         "type": "bank-account",
-        "iban_number": "DE89370400440532013000",
+        "iban": "DE89370400440532013000",
         "id": "bank-acc-1",
     },
-    {"type": "bank-card", "number": "4111111111111111", "id": "bank-card-1"},
+    {"type": "payment-card", "value": "4111111111111111", "id": "payment-card-1"},
     {
         "type": "cryptocurrency-transaction",
         "hash": "abcde98765fghij",
         "id": "crypto-tx-1",
     },
-    {"type": "cryptocurrency-wallet", "hash": "wallet-hash-xyz789", "id": "wallet-1"},
+    {"type": "cryptocurrency-wallet", "value": "wallet-hash-xyz789", "id": "wallet-1"},
     {"type": "directory", "path": "/usr/local/bin", "id": "dir-1"},
     {"type": "domain-name", "value": "example.net", "id": "domain-1"},
     {"type": "email-addr", "value": "user@example.com", "id": "email-1"},
@@ -252,43 +252,43 @@ SCO_VALUE_FILTER_TEST_DATA = test_data = [
         [
             {
                 "type": "bank-account",
-                "iban_number": "DE89370400440532013000",
+                "iban": "DE89370400440532013000",
                 "id": "bank-acc-1",
             }
         ],
         "3201",
         ["bank-acc-1"],
-        id="match-bank-account-on-iban_number",
+        id="match-bank-account-on-iban",
     ),
     pytest.param(
-        [{"type": "bank-card", "number": "4111111111111111", "id": "bank-card-1"}],
+        [{"type": "payment-card", "value": "4111111111111111", "id": "payment-card-1"}],
         "1111",
-        ["bank-card-1"],
-        id="match-bank-card-on-number",
+        ["payment-card-1"],
+        id="match-payment-card-on-value",
     ),
     pytest.param(
         [
             {
                 "type": "cryptocurrency-transaction",
-                "hash": "abcde12345fghij",
+                "value": "abcde12345fghij",
                 "id": "crypto-tx-1",
             }
         ],
         "12345",
         ["crypto-tx-1"],
-        id="match-crypto-tx-on-hash",
+        id="match-crypto-tx-on-value",
     ),
     pytest.param(
         [
             {
                 "type": "cryptocurrency-wallet",
-                "hash": "wallet-hash-xyz789",
+                "value": "wallet-hash-xyz789",
                 "id": "wallet-1",
             }
         ],
         "xyz",
         ["wallet-1"],
-        id="match-crypto-wallet-on-hash",
+        id="match-crypto-wallet-on-value",
     ),
     pytest.param(
         [{"type": "directory", "path": "/usr/local/static/bin", "id": "dir-1"}],
@@ -484,7 +484,7 @@ def sdo_data():
             "type": "weakness",
             "id": "weakness--ac6f22ba-3909-43fa-8f81-1997590a1d7e",
             "labels": ["weak label 1", "strong label 2"],
-            "name": "a weakness object",
+            "name": "a WeakNess object",
             "created": "2023-05-14T11:24:36Z",
             "modified": "2023-05-14T11:24:36Z",
         },
@@ -503,6 +503,12 @@ def sdo_data():
             "name": "another vulnerability object",
             "created": "2021-08-27T22:13:07Z",
             "modified": "2021-08-27T22:13:07Z",
+            "external_references": [
+                {
+                    "source_name": "cve",
+                    "external_id": "CVE-2025-1234",
+                }
+            ],
         },
         {
             "type": "malware",
@@ -511,6 +517,12 @@ def sdo_data():
             "name": "InfoStealer Trojan X",
             "created": "2022-02-14T09:12:44Z",
             "modified": "2023-04-01T15:37:19Z",
+            "external_references": [
+                {
+                    "source_name": "mitre-atlas",
+                    "external_id": "AM0101",
+                }
+            ],
         },
         {
             "type": "tool",
@@ -527,6 +539,7 @@ def sdo_data():
             "name": "APT Zeta",
             "created": "2021-12-07T21:33:10Z",
             "modified": "2021-12-07T21:33:10Z",
+            "x_mitre_domains": ["mobile-attack"],
         },
         {
             "type": "attack-pattern",
@@ -535,6 +548,12 @@ def sdo_data():
             "name": "Email Credential Phishing",
             "created": "2023-09-09T13:59:47Z",
             "modified": "2024-01-20T09:22:15Z",
+            "external_references": [
+                {
+                    "source_name": "DISARM",
+                    "external_id": "DISARM-001",
+                }
+            ],
         },
         {
             "type": "course-of-action",
@@ -543,6 +562,13 @@ def sdo_data():
             "name": "Block Outbound SMTP",
             "created": "2022-06-18T03:18:25Z",
             "modified": "2022-07-01T11:44:38Z",
+            "external_references": [
+                {
+                    "source_name": "mitre-attack",
+                    "external_id": "T1546",
+                }
+            ],
+            "x_mitre_domains": ["ics-attack", "mobile-attack"],
         },
         {
             "type": "intrusion-set",
@@ -578,10 +604,20 @@ def sdo_data():
             ],
         ),
         (
-            dict(types="weakness", name="another"),
+            dict(types="weakness", name="AnoTher"),
             ["weakness--cbd67181-b9f8-595b-8bc3-3971e34fa1cc"],
         ),
         (dict(labels="strong"), ["weakness--ac6f22ba-3909-43fa-8f81-1997590a1d7e"]),
+        (dict(ttp_type='cwe'), ['weakness--ac6f22ba-3909-43fa-8f81-1997590a1d7e', 'weakness--cbd67181-b9f8-595b-8bc3-3971e34fa1cc']),
+        (dict(ttp_type='cve'), ["vulnerability--cbd67181-b9f8-595b-8bc3-3971e34fa1cc"]),
+        (dict(ttp_type='disarm'), ['attack-pattern--54e9c289-8786-44c2-8a60-bf4a541c1140']),
+        (dict(ttp_type='atlas'), ['malware--1d3fcb2b-4718-4a65-9d0b-2f3d823dbf3d']),
+        (dict(ttp_id='AM0101'), ['malware--1d3fcb2b-4718-4a65-9d0b-2f3d823dbf3d']),
+        (dict(ttp_id='DISARM-001'), ['attack-pattern--54e9c289-8786-44c2-8a60-bf4a541c1140']),
+        (dict(ttp_object_type='Software'), ['malware--1d3fcb2b-4718-4a65-9d0b-2f3d823dbf3d', "tool--ea8e1f1e-7d6b-43f7-91b7-4e5b1d22f1a0"]),
+        (dict(ttp_object_type='Software,Group'), ['malware--1d3fcb2b-4718-4a65-9d0b-2f3d823dbf3d', "tool--ea8e1f1e-7d6b-43f7-91b7-4e5b1d22f1a0", "intrusion-set--73470fd9-33a5-4e60-84d6-8b0dc44ad3f4"]),
+        (dict(ttp_id='AM'), []),
+        (dict(ttp_id='AM'), []),
     ],
 )
 def test_sdo_filters(sdo_data, filters, expected_ids):
@@ -589,7 +625,9 @@ def test_sdo_filters(sdo_data, filters, expected_ids):
         conf.ARANGODB_DATABASE_VIEW,
         request_from_queries(**filters),
     )
-    assert {obj["id"] for obj in helper.get_sdos().data["objects"]} == set(expected_ids)
+    objects = helper.get_sdos().data["objects"]
+    print([obj["id"] for obj in objects])
+    assert {obj["id"] for obj in objects} == set(expected_ids)
 
 
 @pytest.mark.parametrize(
